# container-app-conf

This is a library t o easily read application values
from multiple places like a yaml file and environment variables
while providing type validation.

The initial purpose of this library was to have an easy way to configure
applications running inside some kind of container (Docker in this case)
using environment variables while still provide the possibility to use
a more simple form of configuration like a yaml file.

